fnss.topologies.topology.Topology.number_of_edges — FNSS 0.7.0 documentation

# fnss.topologies.topology.Topology.number_of_edges

`Topology.` `number_of_edges`(u=None, v=None)

  Return the number of edges between two nodes.

  Parameters: | u, v : nodes, optional (default=all edges) If u and v are specified, return the number of edges between u and v. Otherwise return the total number of all edges.
  Returns: | nedges : int The number of edges in the graph. If nodes u and v are specified return the number of edges between those nodes.

  See also

  `size`

  Examples

      >>> G = nx.Graph()   # or DiGraph, MultiGraph, MultiDiGraph, etc
      >>> G.add_path([0,1,2,3])
      >>> G.number_of_edges()
      3
      >>> G.number_of_edges(0,1)
      1
      >>> e = (0,1)
      >>> G.number_of_edges(*e)
      1